@@ -42,48 +42,51 @@ test_that("Estimating SPVIMs works", {
   # check that printing, plotting, etc. work
   expect_silent(format(est)[1])
   expect_output(print(est), "Estimate", fixed = TRUE)
+  # check the actual point estimates
+  # expect_equal(sprintf("%.15f", as.numeric(est$est[2])), 
+  #              "0.135665058694294")
 })
 set.seed(1234)
 test_that("Estimating SPVIMs without sample-splitting works", {
-  est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
-                SL.library = learners, gamma = .1, alpha = 0.05, delta = 0,
-                sample_splitting = FALSE,
-                cvControl = list(V = V), env = environment())
+  est_no_ss <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
+                      SL.library = learners, gamma = .1, alpha = 0.05, delta = 0,
+                      sample_splitting = FALSE,
+                      cvControl = list(V = V), env = environment())
   # check that the estimate is approximately correct
-  expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
+  expect_equal(as.numeric(est_no_ss$est[2]), shapley_val_1, tolerance = 0.2)
 })
 set.seed(5678)
 test_that("Estimating SPVIMs with special univariate library works", {
-  est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
-                SL.library = learners, 
-                univariate_SL.library = univariate_learners,
-                gamma = .1, alpha = 0.05, delta = 0,
-                cvControl = list(V = V), env = environment())
+  est_uni <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
+                    SL.library = learners, 
+                    univariate_SL.library = univariate_learners,
+                    gamma = .1, alpha = 0.05, delta = 0,
+                    cvControl = list(V = V), env = environment())
   # check that the estimate is approximately correct
-  expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
+  expect_equal(as.numeric(est_uni$est[2]), shapley_val_1, tolerance = 0.2)
 })
 set.seed(91011)
 test_that("Estimating SPVIMs with a single library function works", {
-  est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
-                SL.library = "SL.glm", 
-                univariate_SL.library = univariate_learners,
-                gamma = .1, alpha = 0.05, delta = 0,
-                cvControl = list(V = V), env = environment())
+  est_single <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
+                       SL.library = "SL.glm", 
+                       univariate_SL.library = univariate_learners,
+                       gamma = .1, alpha = 0.05, delta = 0,
+                       cvControl = list(V = V), env = environment())
   # check that the estimate is approximately correct
-  expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
+  expect_equal(as.numeric(est_single$est[2]), shapley_val_1, tolerance = 0.2)
 })
 set.seed(121314)
 test_that("Estimating SPVIMs with verbose = TRUE works", {
-  expect_message(est <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
-                              SL.library = "SL.glm", 
-                              univariate_SL.library = "SL.glm",
-                              gamma = .1, alpha = 0.05, delta = 0,
-                              cvControl = list(V = V), env = environment(), 
-                              verbose = TRUE),
+  expect_message(est_verbose <- sp_vim(Y = y, X = x, V = V, type = "r_squared",
+                                       SL.library = "SL.glm", 
+                                       univariate_SL.library = "SL.glm",
+                                       gamma = .1, alpha = 0.05, delta = 0,
+                                       cvControl = list(V = V), env = environment(), 
+                                       verbose = TRUE),
                  "Fitting learners",
                  all = FALSE)
   # check that the estimate is approximately correct
-  expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
+  expect_equal(as.numeric(est_verbose$est[2]), shapley_val_1, tolerance = 0.2)
 })
 
 
